/*
 * Copyright (C) 2013 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Arto Jalkanen <ajalkane@gmail.com>
 */
import QtQuick 2.3
import Ubuntu.Components 1.1
import org.nemomobile.folderlistmodel 1.0
import Ubuntu.Components.Popups 1.0
import Ubuntu.Unity.Action 1.1 as UnityActions
import U1db 1.0 as U1db
import Ubuntu.Content 1.0
import com.ubuntu.PlacesModel 0.1
import com.ubuntu.PamAuthentication 0.1

import "ui"

MainView {
    id: mainView
    // objectName for functional testing purposes (autopilot-qt5)
    objectName: "filemanager"
    applicationName: "com.ubuntu.files-app"
    useDeprecatedToolbar: false

    width: phone ? units.gu(40) : units.gu(100)
    height: units.gu(75)

    property alias filemanager: mainView

    property bool loaded: false

    QtObject {
        id: fileSelector
        property var activeTransfer: null
        property var fileSelectorComponent: null
    }

    Component {
        id: fileSelectorResultComponent
        ContentItem {}
    }

    PageStack {
        id: pageStack
    }

    PlacesModel {
       id: userplaces
    }

    property var pageStack: pageStack

    Column {
        id: closeMessage
        anchors.centerIn: parent
        width: parent.width - units.gu(10)
        spacing: units.gu(4)

        Label {
            text: i18n.tr("To use this application import or export content from another app")
            wrapMode: Text.WordWrap
            width: parent.width
            horizontalAlignment: Text.AlignHCenter
        }

        Button {
            text: i18n.tr("Close")
            width: parent.width
            onClicked: Qt.quit()
        }
    }

    function openFileSelector() {
        closeMessage.visible = false
        pageStack.push(fileSelectorComponent, { fileSelectorMode: true} )
    }

    function cancelFileSelector() {
        console.log("Cancel file selector")
        pageStack.pop()
        fileSelector.fileSelectorComponent = null
        fileSelector.activeTransfer.state = ContentTransfer.Aborted
    }

    function acceptFileSelector(fileUrls) {
        console.log("accept file selector " + fileUrls)
        var results = fileUrls.map(function(fileUrl) {
            return fileSelectorResultComponent.createObject(mainView, {"url": fileUrl})
        })

        if (fileSelector.activeTransfer !== null) {
            fileSelector.activeTransfer.items = results
            fileSelector.activeTransfer.state = ContentTransfer.Charged
            console.log("set activeTransfer")
        } else {
            console.log("activeTransfer null, not setting, testing code")
        }
    }

    Connections {
        target: ContentHub
        onImportRequested: {
            fileSelector.activeTransfer = transfer
            openFileSelector()
        }
        onExportRequested: {
            fileSelector.activeTransfer = transfer
            openFileSelector()
        }
    }

    Component {
        id: fileSelectorComponent

        FolderListPage {
            folder: userplaces.locationHome
        }
    }

    function getIcon(name) {
        return "/usr/share/icons/ubuntu-mobile/actions/scalable/" + name + ".svg" //Qt.resolvedUrl("icons/" + name + ".png")
    }

    function error(title, message) {
        PopupUtils.open(Qt.resolvedUrl("NotifyDialog.qml"), mainView,
                        {
                            title: title,
                            text: message
                        })
    }

}
